@@ -1,6 +1,6 @@
 /* Etherape
  * Copyright (C) 2000 Juan Toledo
- * $Id: capture.h,v 1.56 2002/09/22 13:15:26 toledo Exp $
+ * $Id: capture.h,v 1.57 2005/08/13 18:50:13 bchiara Exp $
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,8 +37,6 @@ typedef enum
 }
 create_node_type_t;
 
-static pcap_t *pch;		/* pcap structure */
-static struct pcap_pkthdr phdr;
 
 static guint32 ms_to_next;	/* Used for offline mode to store the amount
 				 * of time that we have to wait between
