@@ -1,6 +1,6 @@
 /* EtherApe
  * Copyright (C) 2001 Juan Toledo
- * $Id: main.c,v 1.87.2.3 2003/02/25 00:05:31 bchiara Exp $
+ * $Id: main.c,v 1.91 2005/08/17 21:20:21 bchiara Exp $
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,8 +21,9 @@
 #include <config.h>
 #endif
 
+#include <netinet/in.h>
 #include "globals.h"
-#include "dns.h"
+#include "ip-cache.h"
 #include "main.h"
 
 
@@ -77,8 +78,7 @@ main (int argc, char *argv[])
 
   /* We initiate the application and read command line options */
   gnome_program_init ("EtherApe", VERSION, LIBGNOMEUI_MODULE, argc, argv,
-		      GNOME_PARAM_POPT_TABLE, optionsTable, 0, NULL);
-//r.g.                           GNOME_PROGRAM_STANDARD_PROPERTIES, NULL);
+		      GNOME_PARAM_POPT_TABLE, optionsTable, GNOME_PARAM_NONE);
 
 
   /* We obtain application parameters 
@@ -177,10 +177,10 @@ main (int argc, char *argv[])
 
   /* Session handling */
   client = gnome_master_client ();
-  gtk_signal_connect (GTK_OBJECT (client), "save_yourself",
-		      GTK_SIGNAL_FUNC (save_session), argv[0]);
-  gtk_signal_connect (GTK_OBJECT (client), "die",
-		      GTK_SIGNAL_FUNC (session_die), NULL);
+  g_signal_connect (G_OBJECT (client), "save_yourself",
+		    GTK_SIGNAL_FUNC (save_session), argv[0]);
+  g_signal_connect (G_OBJECT (client), "die",
+		    GTK_SIGNAL_FUNC (session_die), NULL);
   gtk_widget_show (app1);
 
 
@@ -214,8 +214,8 @@ main (int argc, char *argv[])
   /* This other timeout makes sure that the info windows are updated */
   g_timeout_add (500, (GtkFunction) update_info_windows, NULL);
 
-  /* another timeout to handle DNS time */
-  g_timeout_add (10000, (GtkFunction) dns_tick, NULL);
+  /* another timeout to handle IP-cache timeouts */
+  g_timeout_add (10000, (GtkFunction) ipcache_tick, NULL);
 
   init_menus ();
 
@@ -301,6 +301,15 @@ load_config (char *prefix)
     ("Diagram/colors=#ff0000;WWW #0000ff;DOMAIN #00ff00 #ffff00 #ff00ff #00ffff #ffffff #ff7700 #ff0077 #ffaa77 #7777ff #aaaa33",
      &(pref.n_colors), &(pref.colors), &u);
 
+  if (!pref.n_colors || !pref.colors || !strlen(pref.colors[0]))
+  {
+     /* color array defined in prefs, but empty */
+     pref.n_colors = 1;
+     g_free(pref.colors[0]);
+     pref.colors[0] = g_strdup("#7f7f7f");
+  }
+
+  
   g_free (config_file_version);
   gnome_config_pop_prefix ();
 }				/* load_config */
@@ -437,10 +446,10 @@ session_die (GnomeClient * client, gpointer client_data)
 }				/* session_die */
 
 /* the gnome session manager may call this function */
-static gint
+static gboolean
 save_session (GnomeClient * client, gint phase, GnomeSaveStyle save_style,
-	      gint is_shutdown, GnomeInteractStyle interact_style,
-	      gint is_fast, gpointer client_data)
+	      gboolean is_shutdown, GnomeInteractStyle interact_style,
+	      gboolean is_fast, gpointer client_data)
 {
   gchar **argv;
   guint argc;
