@@ -1,6 +1,6 @@
 /* EtherApe
  * Copyright (C) 2001 Juan Toledo
- * $Id: menus.c,v 1.22.2.4 2003/02/25 22:09:50 bchiara Exp $
+ * $Id: menus.c,v 1.25 2005/08/15 14:24:19 bchiara Exp $
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,6 +23,14 @@
 #include <gtk/gtkcontainer.h>
 #include "util.h"
 
+
+static GnomeUIInfo help_submenu[] = {
+  GNOMEUIINFO_HELP ("etherape"),
+  GNOMEUIINFO_END
+};
+
+static gboolean in_start_capture = FALSE;
+
 #if 0
 /* This is here just as an example in case I need it again */
 void
@@ -57,11 +65,6 @@ init_menus (void)
   /* It seems libglade is not acknowledging the "Use gnome help" option in the 
    * glade file and so it is not automatically adding the help items in the help
    * menu. Thus I must add it manually here */
-/* R.G.
-  widget = glade_xml_get_widget (xml, "help1_menu");
-  gnome_app_fill_menu ((GtkMenuShell *) widget, help_submenu,
-		       gtk_accel_group_get_default (), TRUE, 1);
-*/
   interface_list = get_interface_list (&err, err_str);
 
   interfaces = interface_list;
@@ -80,7 +83,7 @@ init_menus (void)
    * interface */
   item = gtk_radio_menu_item_new_with_label (group, "apedummy");
   group = gtk_radio_menu_item_group (GTK_RADIO_MENU_ITEM (item));
-  gtk_menu_append (GTK_MENU (widget), item);
+  gtk_menu_shell_append (GTK_MENU_SHELL (widget), item);
 
   /* Set up the real interfaces menu entries */
   while (interfaces)
@@ -89,12 +92,12 @@ init_menus (void)
 	gtk_radio_menu_item_new_with_label (group,
 					    (gchar *) (interfaces->data));
       group = gtk_radio_menu_item_group (GTK_RADIO_MENU_ITEM (item));
-      gtk_menu_append (GTK_MENU (widget), item);
+      gtk_menu_shell_append (GTK_MENU_SHELL (widget), item);
       gtk_widget_show (item);
-      gtk_signal_connect_object (GTK_OBJECT (item), "activate",
-				 GTK_SIGNAL_FUNC
-				 (on_interface_radio_activate),
-				 (gpointer) g_strdup (interfaces->data));
+      g_signal_connect_swapped (G_OBJECT (item), "activate",
+				GTK_SIGNAL_FUNC
+				(on_interface_radio_activate),
+				(gpointer) g_strdup (interfaces->data));
       g_string_append (info_string, " ");
       g_string_append (info_string, (gchar *) (interfaces->data));
       interfaces = interfaces->next;
@@ -432,6 +435,9 @@ gui_start_capture (void)
     {
     case L_NULL:
     case L_RAW:
+#ifdef DLT_LINUX_SLL
+    case L_LINUX_SLL:
+#endif
       widget = glade_xml_get_widget (xml, "ieee802_radio");
       gtk_widget_set_sensitive (widget, FALSE);
       widget = glade_xml_get_widget (xml, "fddi_radio");
@@ -448,6 +454,9 @@ gui_start_capture (void)
       gtk_widget_set_sensitive (widget, FALSE);
       break;
     case L_EN10MB:
+#ifdef DLT_IEEE802_11
+    case L_IEEE802_11:
+#endif
       widget = glade_xml_get_widget (xml, "fddi_radio");
       gtk_widget_set_sensitive (widget, FALSE);
       widget = glade_xml_get_widget (xml, "ethernet_radio");
@@ -464,6 +473,7 @@ gui_start_capture (void)
       gtk_widget_set_sensitive (widget, TRUE);
       break;
     default:
+      g_warning (_("Invalid link type %d"), linktype);
       return;
     }
 
@@ -489,6 +499,9 @@ gui_start_capture (void)
     case UDP:
       widget = glade_xml_get_widget (xml, "udp_radio");
       break;
+    default:
+      g_warning (_("Invalid mode: %d"), pref.mode);
+      return;
     }
   gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (widget), TRUE);
 
@@ -526,6 +539,9 @@ gui_start_capture (void)
     case UDP:
       g_string_append (status_string, _(" in UDP mode"));
       break;
+    default:
+      g_critical (_("Invalid mode: %d"), pref.mode);
+      return;
     }
 
   set_appbar_status (status_string->str);
@@ -662,13 +678,11 @@ fatal_error_dialog (const gchar * message)
 {
   GtkWidget *error_messagebox;
 
-  /* TODO I am not very sure I am not leaking with this, but this is 
-   * extraordinary and would hardly be noticeable */
-
-  error_messagebox = gnome_message_box_new (message,
-					    GNOME_MESSAGE_BOX_ERROR,
-					    GNOME_STOCK_BUTTON_OK, NULL);
-  gtk_widget_show (error_messagebox);
+  error_messagebox = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL,
+					     GTK_MESSAGE_ERROR,
+					     GTK_BUTTONS_OK, message);
+  gtk_dialog_run (GTK_DIALOG (error_messagebox));
+  gtk_widget_destroy (error_messagebox);
 
 }				/* fatal_error_dialog */
 
