@@ -1,6 +1,6 @@
 /* EtherApe
  * Copyright (C) 2001 Juan Toledo
- * $Id: menus.h,v 1.8.2.1 2003/02/22 09:36:09 bchiara Exp $
+ * $Id: menus.h,v 1.9 2003/04/06 13:45:42 bchiara Exp $
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,13 +29,6 @@
 
 GList *interface_list = NULL;	/* A list of all usable interface */
 
-static GnomeUIInfo help_submenu[] = {
-  GNOMEUIINFO_HELP ("etherape"),
-  GNOMEUIINFO_END
-};
-
-static gboolean in_start_capture;
-
 void on_open_activate (GtkMenuItem * menuitem, gpointer user_data);
 void on_file_cancel_button_clicked (GtkButton * button, gpointer user_data);
 void on_file_combo_entry_changed (GtkEditable * editable, gpointer user_data);
@@ -45,6 +38,7 @@ void on_interface_radio_activate (gchar * gui_device);
 void on_mode_radio_activate (GtkMenuItem * menuitem, gpointer user_data);
 void on_start_menuitem_activate (GtkMenuItem * menuitem, gpointer user_data);
 void on_stop_menuitem_activate (GtkMenuItem * menuitem, gpointer user_data);
+void on_pause_menuitem_activate (GtkMenuItem * menuitem, gpointer user_data);
 
 void on_toolbar_check_activate (GtkCheckMenuItem * menuitem,
 				gpointer user_data);
