@@ -1,6 +1,6 @@
 /* Etherape
  * Copyright (C) 2000 Juan Toledo
- * $Id: preferences.h,v 1.6.2.1 2003/02/22 09:36:09 bchiara Exp $
+ * $Id: preferences.h,v 1.7 2003/04/06 13:45:42 bchiara Exp $
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -54,4 +54,10 @@ void on_ok_pref_button_clicked (GtkButton * button, gpointer user_data);
 void on_cancel_pref_button_clicked (GtkButton * button, gpointer user_data);
 void on_protocol_edit_dialog_show (GtkWidget * wdg, gpointer user_data);
 
+void on_group_unk_check_toggled (GtkToggleButton * togglebutton, gpointer);
+void on_aa_check_toggled (GtkToggleButton * togglebutton, gpointer user_data);
+void on_fade_toggle_toggled (GtkToggleButton * togglebutton, gpointer udata);
+void on_cycle_toggle_toggled (GtkToggleButton * togglebutton, gpointer udata);
+
+
 void color_list_to_pref (void);
